use std::{cell::RefCell, collections::HashMap, sync::{Arc, Mutex, OnceLock, RwLock}};

use fluent::{FluentBundle, FluentResource};

use lazy_static::lazy_static;

pub mod en_us;
pub mod zh_cn;

// static I18N: OnceLock<HashMap<&str, Arc<FluentBundle<FluentResource>>>> = OnceLock::new();

lazy_static!{
    pub static ref I18N_MAP: RwLock<HashMap<&static str, Arc<FluentBundle<FluentResource>>>> = {
        init_i18n()
    };
}

pub fn init_i18n() -> RwLock<HashMap<&'static str, Arc<FluentBundle<FluentResource>>>> {
    // 英文资源初始化
    let langid_en_us = "en-US".parse().expect("初始化英文标识失败");
    let en_us_res = FluentResource::try_new(en_us::MESSAGE.to_string()).expect("初始化英文资源失败");
    let mut en_us_bundle = FluentBundle::new(vec![langid_en_us]);
    en_us_bundle.add_resource(en_us_res).expect("添加英文资源失败");

    // 简体中文资源初始化
    let langid_zh_cn = "en-US".parse().expect("初始化简体中文标识失败");
    let zh_cn_res = FluentResource::try_new(en_us::MESSAGE.to_string()).expect("初始化简体中文资源失败");
    let mut zj_cn_bundle = FluentBundle::new(vec![langid_zh_cn]);
    zj_cn_bundle.add_resource(zh_cn_res).expect("添加简体中文资源失败");

    let mut map = HashMap::new();
    map.insert("en-US", Arc::new(en_us_bundle));
    map.insert("zh-CN", Arc::new(zj_cn_bundle));
    RwLock::new(map)
}